Learn R Programming

earthdatalogin (version 0.0.2)

edl_revoke_token: Revoke an EarthData token

Description

Users can only have at most 2 active tokens at any time. You don't need to keep track of a token since earthdatalogin can retrieve your tokens with your user name and password. However, should you want to revoke a token, you can do so with this function.

Usage

edl_revoke_token(
  username = default("user"),
  password = default("password"),
  token_number = 1
)

Value

API response (invisibly)

Arguments

username

EarthData Login User

password

EarthData Login Password

token_number

Which token (1 or 2)

Examples

Run this code
if (FALSE) { # interactive()
edl_revoke_token()
}

Run the code above in your browser using DataLab