Note that this function should rarely be necessary, as unlike bearer
token-based auth, netrc is mapped by domain name and will not interfere
with access to non-earthdata-based URLs. It may still be necessary
to deactivate in order to use one of the other earthdatalogin authentication
methods.
To unset environmental variables without removing files, set that file
path argument to "" (see examples)
Note that GDAL_HTTP_NETRC defaults to YES.