Users can only have at most 2 active tokens at any time.
You don't need to keep track of a token since earthdatalogin can
retrieve your tokens with your user name and password. However,
should you want to revoke a token, you can do so with this function.