edl_s3_token: Receive and set temporary AWS Tokens for S3 access
Description
Note that these S3 credentials will only work:
Usage
edl_s3_token(
daac = "https://data.lpdaac.earthdatacloud.nasa.gov",
username = default("user"),
password = default("password"),
prompt_for_netrc = interactive()
)Value
list of access key, secret key, session token and expiration,
invisibly. Also sets the corresponding AWS environmental variables.
Arguments
- daac
the base URL for the DAAC
- username
EarthDataLogin user
- password
EarthDataLogin Password
- prompt_for_netrc
Often netrc is preferable, so this function will by
default prompt the user to switch. Set to FALSE to silence this.
Details
On AWS instance in the us-west-2 region
Only for one hour before they expire
Only on the DAAC requested
Please consider using edl_netrc() to avoid these limitations
Examples
Run this codeif (FALSE) { # interactive()
edl_s3_token()
}
Run the code above in your browser using DataLab